check_for_updates

Function check_for_updates 

pub fn check_for_updates(_interval_hours: u64) -> Option<UpdateInfo>
Check for updates using update-informer

This function respects the check interval configured by the user. Results are cached by update-informer to prevent excessive API calls.

Arguments

  • interval_hours - How often to check for updates (in hours)

Returns

  • Some(UpdateInfo) if a newer version is available
  • None if already up to date or check failed/skipped